@@ -10,7 +10,7 @@
 setClass("RangedSummarizedExperiment",
     contains="SummarizedExperiment",
     representation(
-        rowRanges="GenomicRangesORGRangesList"
+        rowRanges="GenomicRanges_OR_GRangesList"
     ),
     prototype(
         rowRanges=GRanges()
@@ -111,7 +111,7 @@ setMethod("SummarizedExperiment", "SimpleList",
     } else {
         if (!missing(rowRanges))
             stop("only one of 'rowData' and 'rowRanges' can be specified")
-        if (is(rowData, "GenomicRangesORGRangesList")) {
+        if (is(rowData, "GenomicRanges_OR_GRangesList")) {
             rowRanges <- rowData
             if (is.null(names(rowRanges)))
                 names(rowRanges) <- .get_rownames_from_assays(assays)
@@ -145,7 +145,7 @@ setMethod("SummarizedExperiment", "SimpleList",
 
     assays <- Assays(assays)
 
-    if (missing(rowRanges) && !is(rowData, "GenomicRangesORGRangesList")) {
+    if (missing(rowRanges) && !is(rowData, "GenomicRanges_OR_GRangesList")) {
         new_SummarizedExperiment(assays, ans_rownames, rowData, colData,
                                  metadata)
     } else {
@@ -199,6 +199,7 @@ setAs("RangedSummarizedExperiment", "SummarizedExperiment",
 {
     partitioning <- PartitioningByEnd(integer(length(from)), names=names(from))
     rowRanges <- relist(GRanges(), partitioning)
+    mcols(rowRanges) <- mcols(from)
     .new_RangedSummarizedExperiment(from@assays,
                                     rowRanges,
                                     from@colData,
@@ -480,7 +481,7 @@ setMethod("seqinfo", "RangedSummarizedExperiment",
 })
 
 setReplaceMethod("seqinfo", "RangedSummarizedExperiment",
-    function (x, new2old= NULL, force=FALSE,
+    function (x, new2old= NULL,
               pruning.mode=c("error", "coarse", "fine", "tidy"),
               value)
 {
@@ -488,7 +489,6 @@ setReplaceMethod("seqinfo", "RangedSummarizedExperiment",
         stop("the supplied 'seqinfo' must be a Seqinfo object")
     dangling_seqlevels <-
         GenomeInfoDb:::getDanglingSeqlevels(x@rowRanges, new2old=new2old,
-                                            force=force,
                                             pruning.mode=pruning.mode,
                                             seqlevels(value))
     if (length(dangling_seqlevels) != 0L) 
