@@ -9,7 +9,7 @@ setClass("SummarizedExperiment",
     representation(
         colData="DataFrame",              # columns and their annotations
         assays="Assays",                  # Data -- e.g., list of matricies
-        NAMES="characterORNULL",
+        NAMES="character_OR_NULL",
         elementMetadata="DataFrame"
     ),
     prototype(
@@ -17,10 +17,6 @@ setClass("SummarizedExperiment",
     )
 )
 
-### Temporary, for backward compatibility only.
-### TODO: Remove in BioC 3.4.
-setClass("SummarizedExperiment0", contains="SummarizedExperiment")
-
 ### Combine the new parallel slots with those of the parent class. Make sure
 ### to put the new parallel slots *first*.
 setMethod("parallelSlotNames", "SummarizedExperiment",
@@ -564,7 +560,7 @@ setReplaceMethod("[[", c("SummarizedExperiment", "ANY", "missing"),
     x
 })
 
-.DollarNames.SummarizedExperiment <- function(x, pattern)
+.DollarNames.SummarizedExperiment <- function(x, pattern = "")
     grep(pattern, names(colData(x)), value=TRUE)
 
 setMethod("$", "SummarizedExperiment",
@@ -819,3 +815,30 @@ setMethod("identicalVals", c("GenomicRanges", "GenomicRanges"),
     }
 )
 
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### On-disk realization.
+###
+
+setMethod("realize", "SummarizedExperiment",
+    function(x)
+    {
+        for (i in seq_along(assays(x))) {
+            ## We drop the dimnames of the individual assays for 2 reasons:
+            ##   1) These dimnames are kind of irrelevant. The dimnames that
+            ##      really matter are 'dimnames(x)' and they are stored
+            ##      somewhere else in 'x'. So we don't loose them by not
+            ##      realizing the assay dimnames on disk. As a little extra
+            ##      bonus, this actually saves a little bit of time and disk
+            ##      space.
+            ##   2) Using the HDF5Array backend to realize an array-like object
+            ##      on disk doesn't store the dimnames in the HDF5 file at the
+            ##      moment.
+            a <- assay(x, i, withDimnames=FALSE)
+            dimnames(a) <- NULL
+            assay(x, i) <- realize(a)
+        }
+        x
+    }
+)
+
